@@ -31,11 +31,13 @@ globalVariables(
     "N",
     "n",
     "noise",
+    "outcome_sd",
     "posterior_H",
     "R",
     "R_Z_0",
     "R_Z_1",
     "sensitive_trait",
+    "setNames",
     "test_results",
     "type",
     "u",
@@ -43,6 +45,7 @@ globalVariables(
     "u_a",
     "u_R",
     "u_t1",
+    "u_W",
     "U_Z", 
     "withholder",
     "X",
