@@ -149,16 +149,16 @@ attr(binary_iv_designer, "definitions") <- data.frame(
   names         = c("N", "type_probs", "assignment_probs", "a_Y", "b_Y", "d_Y",
                     "outcome_sd", "a", "b", "d", "args_to_fix"),
   tips          = c("Sample size",
-                    "Probability of each complier type",
+                    "Probability of each complier type (order: always-taker, never-taker, complier, defier)",
                     "Probability of assignment to encouragement", 
-                    "Constant in Y equation for each complier type",
+                    "Constant in Y equation for each complier type (order: always-taker, never-taker, complier, defier)",
                     "Effect of X on Y",
                     "Effect of Z on Y",
-                    "Standard deviation of the outcome.",
+                    "Standard deviation of the outcome",
                     "Constant in Y equation", 
                     "Slope on X in Y equation for each complier type", 
                     "Slope on Z in Y equation for each complier type",
-                    "Names of arguments to be args_to_fix"),
+                    "Names of arguments to be fixed"),
   class         = c("integer", rep("numeric", 9), "character"),
   vector = c(FALSE, TRUE, TRUE, rep(FALSE, 4), TRUE, TRUE, TRUE, TRUE),
   min           = c(4, 0, 0, rep(-Inf, 3), 0, rep(-Inf, 3), NA),
