@@ -271,13 +271,13 @@ attr(factorial_designer,"definitions") <- data.frame(
                     "args_to_fix"),
   tips          = c("Size of sample",
                     "The number of factors in the design",
-                    "Means for each of the treatment combinations",
-                    "Standard deviation for outcomes",
+                    "Means for each of the treatment combinations. The order is obtained by varying the assignment to the first treatment in every other element in the order, the second after every two elements, the third after every 2^2 elements and so forth, starting with 0.",
+                    "Standard deviation for outcomes. The order is obtained by varying the assignment to the first treatment in every other element in the order, the second after every two elements, the third after every 2^2 elements and so forth, starting with 0.",
                     "Standard deviations for each of the treatment combinations",
                     "Independent probability of assignment to each treatment",
                     "Name of outcome variable",
                     "Name of treatment factors variable",
-                    "Names of arguments to be args_to_fix"),
+                    "Names of arguments to be fixed"),
   class         = c("integer", "integer", rep("numeric", 4), rep("character", 3)),
   vector = c(FALSE, FALSE, TRUE, FALSE, TRUE, TRUE, FALSE, TRUE, TRUE),
   min           = c(2, 2, -Inf, rep(0, 3), rep(NA, 3)),
